@@ -6,14 +6,14 @@
  *      Description:  Types file for topology module. External definitions are
  *                    in likwid.h
  *
- *      Version:   4.3.4
- *      Released:  05.04.2019
+ *      Version:   5.2.2
+ *      Released:  26.07.2022
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com,
- *                Thomas Roehl (tr), thomas.roehl@googlemail.com
+ *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2019 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -60,6 +60,7 @@ typedef enum {
     SSSE3, /*!< \brief Supplemental Streaming SIMD Extensions 3 */
     SSE41, /*!< \brief Streaming SIMD Extensions 4.1 */
     SSE42, /*!< \brief Streaming SIMD Extensions 4.2 */
+    SSE4A, /*!< \brief Streaming SIMD Extensions 4A */
     AVX, /*!< \brief Advanced Vector Extensions */
     FMA, /*!< \brief Fused multiply-add (FMA3) */
     AVX2, /*!< \brief Advanced Vector Extensions 2 */
@@ -68,6 +69,18 @@ typedef enum {
     HTT, /*!< \brief Hyper-Threading Technology */
     RDSEED, /*!< \brief Non-deterministic random bit generator */
     AVX512, /*!< \brief 512-bit wide vector registers for Advanced Vector Extensions */
+    SWP, /*!< \brief Atomic read-modify-write */
+    VFP, /*!< \brief First generation SIMD */
+    NEON, /*!< \brief Second generation SIMD */
+    EDSP, /*!< \brief DSP extensions */
+    VFPV3, /*!< \brief First generation SIMD Version 3 */
+    VFPV4, /*!< \brief First generation SIMD Version 4 */
+    TLS, /*!< \brief Thread-local storage registers */
+    FP, /*!< \brief Floating-point support */
+    ASIMD, /*!< \brief ARMv8 Advanced SIMD */
+    ASIMDRDM, /*!< \brief ARMv8 Advanced SIMD: Rounding double multiply */
+    PMULL, /*!< \brief ARMv8 Advanced SIMD: Polynomial multiply long */
+    SVE, /*!< \brief ARMv8 Scalable Vector Extension */
 } FeatureBit;
 /** @}*/
 #endif /*CPUID_TYPES_H*/
